@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001,2002 Red Hat, Inc.
+ * Copyright (C) 2001,2002,2003 Red Hat, Inc.
  *
  * This is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Library General Public License as published by
@@ -19,7 +19,7 @@
 #ifndef vte_vte_h_included
 #define vte_vte_h_included
 
-#ident "$Id: vte.h,v 1.52 2002/10/25 22:07:11 nalin Exp $"
+#ident "$Id: vte.h,v 1.65 2003/04/24 03:03:51 nalin Exp $"
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -75,6 +75,8 @@ struct _VteTerminalClass {
 	guint selection_changed_signal;
 	guint contents_changed_signal;
 	guint cursor_moved_signal;
+	guint status_line_changed_signal;
+	guint commit_signal;
 
 	guint deiconify_window_signal;
 	guint iconify_window_signal;
@@ -85,13 +87,21 @@ struct _VteTerminalClass {
 	guint maximize_window_signal;
 	guint resize_window_signal;
 	guint move_window_signal;
-	guint status_line_changed_signal;
-	guint commit_signal;
 
-	gpointer reserved1;
-	gpointer reserved2;
-	gpointer reserved3;
-	gpointer reserved4;
+	guint increase_font_size_signal;
+	guint decrease_font_size_signal;
+
+	guint text_modified_signal;
+	guint text_inserted_signal;
+	guint text_deleted_signal;
+	guint text_scrolled_signal;
+
+	guint reserved1;
+	guint reserved2;
+	guint reserved3;
+	guint reserved4;
+	guint reserved5;
+	guint reserved6;
 };
 
 /* Values for "what should happen when the user hits backspace/delete".  Use
@@ -104,11 +114,12 @@ typedef enum {
 } VteTerminalEraseBinding;
 
 /* The structure we return as the supplemental attributes for strings. */
-struct vte_char_attributes {
+struct _VteCharAttributes {
 	long row, column;
 	GdkColor fore, back;
-	gboolean underline, alternate;
+	gboolean underline:1, strikethrough:1;
 };
+typedef struct _VteCharAttributes VteCharAttributes;
 
 /* The widget's type. */
 GtkType vte_terminal_get_type(void);
@@ -162,11 +173,14 @@ void vte_terminal_set_audible_bell(VteTerminal *terminal, gboolean is_audible);
 gboolean vte_terminal_get_audible_bell(VteTerminal *terminal);
 void vte_terminal_set_visible_bell(VteTerminal *terminal, gboolean is_visible);
 gboolean vte_terminal_get_visible_bell(VteTerminal *terminal);
+void vte_terminal_set_scroll_background(VteTerminal *terminal, gboolean scroll);
 void vte_terminal_set_scroll_on_output(VteTerminal *terminal, gboolean scroll);
 void vte_terminal_set_scroll_on_keystroke(VteTerminal *terminal,
 					  gboolean scroll);
 
 /* Set the color scheme. */
+void vte_terminal_set_color_dim(VteTerminal *terminal,
+				const GdkColor *dim);
 void vte_terminal_set_color_bold(VteTerminal *terminal,
 				 const GdkColor *bold);
 void vte_terminal_set_color_foreground(VteTerminal *terminal,
@@ -184,6 +198,8 @@ void vte_terminal_set_default_colors(VteTerminal *terminal);
 void vte_terminal_set_background_image(VteTerminal *terminal, GdkPixbuf *image);
 void vte_terminal_set_background_image_file(VteTerminal *terminal,
 					    const char *path);
+void vte_terminal_set_background_tint_color(VteTerminal *terminal,
+					    const GdkColor *color);
 void vte_terminal_set_background_saturation(VteTerminal *terminal,
 					    double saturation);
 void vte_terminal_set_background_transparent(VteTerminal *terminal,
@@ -234,7 +250,7 @@ void vte_terminal_reset(VteTerminal *terminal, gboolean full,
 /* Read the contents of the terminal, using a callback function to determine
  * if a particular location on the screen (0-based) is interesting enough to
  * include.  Each byte in the returned string will have a corresponding
- * struct vte_char_attributes in the passed GArray, if the array was not NULL.
+ * VteCharAttributes structure in the passed GArray, if the array was not NULL.
  * Note that it will have one entry per byte, not per character, so indexes
  * should match up exactly. */
 char *vte_terminal_get_text(VteTerminal *terminal,
@@ -262,6 +278,11 @@ void vte_terminal_match_clear_all(VteTerminal *terminal);
 /* Add a matching expression, returning the tag the widget assigns to that
  * expression. */
 int vte_terminal_match_add(VteTerminal *terminal, const char *match);
+/* Set the cursor to be used when the pointer is over a given match. */
+void vte_terminal_match_set_cursor(VteTerminal *terminal, int tag,
+				   GdkCursor *cursor);
+/* Remove a matching expression by tag. */
+void vte_terminal_match_remove(VteTerminal *terminal, int tag);
 
 /* Check if a given cell on the screen contains part of a matched string.  If
  * it does, return the string, and store the match tag in the optional tag
@@ -295,6 +316,9 @@ glong vte_terminal_get_column_count(VteTerminal *terminal);
 const char *vte_terminal_get_window_title(VteTerminal *terminal);
 const char *vte_terminal_get_icon_title(VteTerminal *terminal);
 
+/* You never saw this. */
+void _vte_terminal_accessible_ref(VteTerminal *terminal);
+
 G_END_DECLS
 
 #endif
