@@ -16,8 +16,10 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vteapp.c,v 1.51 2003/03/05 22:31:07 nalin Exp $"
+#ident "$Id: vteapp.c,v 1.55 2003/04/22 04:29:56 nalin Exp $"
+
 #include "../config.h"
+
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -30,7 +32,6 @@
 #endif
 #include "debug.h"
 #include "vte.h"
-#include <gdk/gdkx.h>
 
 #ifdef ENABLE_NLS
 #include <libintl.h>
@@ -296,17 +297,6 @@ decrease_font_size(GtkWidget *widget, gpointer data)
 	adjust_font_size(widget, data, -1);
 }
 
-static void
-mess_with_fontconfig(void)
-{
-#ifdef HAVE_XFT2
-	/* Is this even a good idea?  Probably not, since this doesn't expose
-	 * these fonts to the gnome-font-properties capplet. */
-	FcInit();
-	FcConfigAppFontAddDir(NULL, DATADIR "/" PACKAGE "/fonts");
-#endif
-}
-
 static gboolean
 read_and_feed(GIOChannel *source, GIOCondition condition, gpointer data)
 {
@@ -341,8 +331,6 @@ static void
 take_xconsole_ownership(GtkWidget *widget, gpointer data)
 {
 	char *name, hostname[255];
-	GdkDisplay *display;
-	Atom xatom;
 	GdkAtom atom;
 	GtkClipboard *clipboard;
 	GtkTargetEntry targets[] = {
@@ -354,11 +342,9 @@ take_xconsole_ownership(GtkWidget *widget, gpointer data)
 
 	memset(hostname, '\0', sizeof(hostname));
 	gethostname(hostname, sizeof(hostname) - 1);
-	display = gdk_display_get_default();
 
 	name = g_strdup_printf("MIT_CONSOLE_%s", hostname);
-	xatom = gdk_x11_get_xatom_by_name_for_display(display, name);
-	atom = gdk_x11_xatom_to_atom_for_display(display, xatom);
+	atom = gdk_atom_intern(name, FALSE);
 	clipboard = gtk_clipboard_get(atom);
 	g_free(name);
 
@@ -434,8 +420,10 @@ main(int argc, char **argv)
 	}
 	argv2[i] = NULL;
 	g_assert(i < (g_list_length(args) + 2));
+
 	/* Parse some command-line options. */
-	while ((opt = getopt(argc, argv, "B:CDT2abc:df:ghn:st:w:")) != -1) {
+	while ((opt = getopt(argc, argv, "B:CDT2abc:df:ghn:st:w:-")) != -1) {
+		gboolean bail = FALSE;
 		switch (opt) {
 			case 'B':
 				background = optarg;
@@ -485,12 +473,18 @@ main(int argc, char **argv)
 			case 'w':
 				working_directory = optarg;
 				break;
+			case '-':
+				bail = TRUE;
+				break;
 			case 'h':
 			default:
 				g_print(usage, argv[0]);
 				exit(1);
 				break;
 		}
+		if (bail) {
+			break;
+		}
 	}
 
 	gtk_init(&argc, &argv);
@@ -590,9 +584,6 @@ main(int argc, char **argv)
 		vte_terminal_set_emulation(VTE_TERMINAL(widget), terminal);
 	}
 
-	/* Mess with our fontconfig setup. */
-	mess_with_fontconfig();
-
 	/* Set the default font. */
 	if (font != NULL) {
 		vte_terminal_set_font_from_string(VTE_TERMINAL(widget), font);
