@@ -16,9 +16,10 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vteglyph.c,v 1.5 2003/04/18 00:14:55 nalin Exp $"
+#ident "$Id: vteglyph.c,v 1.9 2003/04/30 18:35:39 nalin Exp $"
 
 #include "../config.h"
+
 #include <sys/param.h>
 #include <math.h>
 #include <gdk/gdk.h>
@@ -28,6 +29,14 @@
 #include "vtefc.h"
 #include "vteglyph.h"
 
+#ifdef ENABLE_NLS
+#include <libintl.h>
+#define _(String) dgettext(PACKAGE, String)
+#else
+#define _(String) String
+#define bindtextdomain(package,dir)
+#endif
+
 #define FONT_INDEX_FUDGE 10
 #define CHAR_WIDTH_FUDGE 10
 #define INVALID_GLYPH    -1
@@ -512,34 +521,34 @@ _vte_glyph_get(struct _vte_glyph_cache *cache, gunichar c)
 			ioffset *= (-face->glyph->bitmap.pitch);
 		}
 		switch (face->glyph->bitmap.pixel_mode) {
-#ifdef HAVE_DECL_FT_PIXEL_MODE_MONO
+#if HAVE_DECL_FT_PIXEL_MODE_MONO
 		case FT_PIXEL_MODE_MONO:
 #else
-#ifdef HAVE_DECL_ft_pixel_mode_mono
+#if HAVE_DECL_ft_pixel_mode_mono
 		case ft_pixel_mode_mono:
 #else
-#error Neither ft_pixel_mode_mono nor FT_PIXEL_MODE_MONO is defined!
+#error "Neither ft_pixel_mode_mono nor FT_PIXEL_MODE_MONO is defined!"
 #endif
 #endif
 			ioffset += (x / 8);
 			t = (face->glyph->bitmap.buffer[ioffset] << (x % 8));
 			r = g = b = (t >> 7) ? 0xff : 0;
 			break;
-#ifdef HAVE_DECL_FT_PIXEL_MODE_GRAY2
+#if HAVE_DECL_FT_PIXEL_MODE_GRAY2
 		case FT_PIXEL_MODE_GRAY2:
 			ioffset += (x / 4);
 			t = (face->glyph->bitmap.buffer[ioffset] << ((x % 4) * 2));
 			r = g = b = CLAMP((t >> 6) * 0x55, 0, 0xff);
 			break;
 #endif
-#ifdef HAVE_DECL_FT_PIXEL_MODE_GRAY4
+#if HAVE_DECL_FT_PIXEL_MODE_GRAY4
 		case FT_PIXEL_MODE_GRAY4:
 			ioffset += (x / 2);
 			t = (face->glyph->bitmap.buffer[ioffset] << ((x % 2) * 4)) & 7;
 			r = g = b = CLAMP((t >> 4) * 0x25, 0, 0xff);
 			break;
 #endif
-#ifdef HAVE_DECL_FT_PIXEL_MODE_LCD
+#if HAVE_DECL_FT_PIXEL_MODE_LCD
 		case FT_PIXEL_MODE_LCD:
 		case FT_PIXEL_MODE_LCD_V:
 			ioffset += (x * 3);
@@ -548,20 +557,20 @@ _vte_glyph_get(struct _vte_glyph_cache *cache, gunichar c)
 			b = face->glyph->bitmap.buffer[ioffset++];
 			break;
 #endif
-#ifdef HAVE_DECL_FT_PIXEL_MODE_GRAY
+#if HAVE_DECL_FT_PIXEL_MODE_GRAY
 		case FT_PIXEL_MODE_GRAY:
 #else
-#ifdef HAVE_DECL_ft_pixel_mode_grays
+#if HAVE_DECL_ft_pixel_mode_grays
 		case ft_pixel_mode_grays:
 #else
-#error Neither FT_PIXEL_MODE_GRAY nor ft_pixel_mode_grays is defined!
+#error "Neither FT_PIXEL_MODE_GRAY nor ft_pixel_mode_grays is defined!"
 #endif
 #endif
 			ioffset += x;
 			r = g = b = face->glyph->bitmap.buffer[ioffset];
 			break;
 		default:
-			g_error("Unknown pixel mode %d.\n",
+			g_error(_("Unknown pixel mode %d.\n"),
 				face->glyph->bitmap.pixel_mode);
 			r = g = b = 0;
 			g_assert_not_reached();
